unit Walpaper;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, Menus, ComAbout, DsgnIntf;

type
  TWallPaper = class(TCustomPanel)
  private
    { Private declarations }
    FGlyph: TBitmap;
    FAbout: string;
    procedure DrawWallPaper;
    procedure SetGlyph(Value: TBitmap);
  protected
    { Protected declarations }
    {$IFDEF WIN32}
    procedure ValidateRename(AComponent: TComponent; const CurName, NewName: string);  override;
    {$ENDIF}
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Paint; override;
  published
    { Published declarations }
    property Glyph: TBitmap read FGlyph write SetGlyph;

    property Align;
    property BorderStyle;
    property HelpContext;
    property Hint;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property TabOrder;
    property TabStop;
    property Visible;

    property OnClick;
    property OnDblClick;
    property OnEnter;
    property OnExit;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;

    property About: string read FAbout write FAbout;
  end;


      { AboutTypeProperty }

type
  TAboutTypeProperty = class(TPropertyEditor)
  private

  public
     function GetValue: string; override;
     procedure SetValue(const Value: string); override;
     procedure Edit; override;
     function GetAttributes: TPropertyAttributes; override;
  end;

var
   AboutWallPaper: TAboutComponent;


procedure Register;
procedure RunAboutBox;

implementation

procedure Register;
begin
  RegisterComponents('BealeARTS', [TWallPaper]);
  RegisterPropertyEditor(TypeInfo(string), TWallPaper, 'About', TAboutTypeProperty);
end;


{$IFDEF WIN32}
procedure TWallPaper.ValidateRename(AComponent: TComponent;
  const CurName, NewName: string);
begin
  if (AComponent <> nil) and (CompareText(CurName, NewName) <> 0) and
    (FindComponent(NewName) <> nil) then
    raise EComponentError.CreateFmt('A component named %s already exists.', [NewName]);
end;
{$ENDIF}


constructor TWallPaper.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);

Width := 150;
Height := 100;
BevelOuter := bvNone;

FGlyph := TBitmap.Create;

end;



destructor TWallPaper.Destroy;
begin

FGlyph.Free;

  inherited Destroy;
end;



procedure TWallPaper.DrawWallPaper;
var
   X,Y: integer;
begin

if FGlyph.Width or FGlyph.Height = 0 then Exit;

for X := 0 to Round(Width/FGlyph.Width) do
for Y := 0 to Round(Height/FGlyph.Height) do
    Canvas.Draw(X*FGlyph.Width, Y*FGlyph.Height, FGlyph);

end;



procedure TWallPaper.Paint;
begin
Caption := '';
   inherited Paint;
DrawWallPaper;
end;




procedure TWallPaper.SetGlyph(Value: TBitmap);
begin
  FGlyph.Assign(Value);
  Paint;
end;



procedure RunAboutBox;
begin
 { Create dialog in memory }
     AboutWallPaper := TAboutComponent.Create(Application);

     { Set dialog strings }
     AboutWallPaper.ProductName.Caption := 'WallPaper';
     AboutWallPaper.Caption := 'About WallPaper';
     AboutWallPaper.Copyright.Caption := 'Copyright 1998, David Beale';

AboutWallPaper.Memo.Lines.Add('Properties');
AboutWallPaper.Memo.Lines.Add('_______________________________________________');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('About - String');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Displays this about dialog. Performs no function when set from within your code.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Align - TAlign');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Determines how the control aligns within its container.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('BorderStyle - TBorderStyle');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Determines whether the control has a border.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Cursor - TCursor');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Cursor used by control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Glyph - TBitmap');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Bitmap to use as wallpaper tile.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Height - Integer');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Vertical size of the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('HelpContext - THelpContext');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Context number for use in calling context-sensitive online Help.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Hint - String');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Control hint message.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Left - Integer');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Horizontal coordinate of the left edge of the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Name - String');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Name of this component, ie WallPaper1.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('ParentShowHint - Boolean');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Determines where the control looks to find out if Help Hint should be show.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('PopupMenu - TPopupMenu');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Identifies the name of the control''s pop-up menu.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('ShowHint - Boolean');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Determines if the control should display a Help Hint.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('TabOrder - TTabOrder');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Indicates the position of the control in its parent''s tab order.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('TabStop - Boolean');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Determines if the user can tab to a control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Tag - LongInt');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Components Tag.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Top - Integer');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Vertical coordinate of the top edge of the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Visible - Boolean');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Determines whether the control appears onscreen.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Width - Integer');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Horizontal size of the control.');

AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Events');
AboutWallPaper.Memo.Lines.Add('_______________________________________________');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnClick - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when the user clicks the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnDblClick - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when the user double-clicks the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnEnter - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when a control becomes active.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnExit - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when the input focus shifts away from the control to another.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnMouseDown - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when the user presses a mouse button with the mouse pointer over the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnMouseMove - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when the user moves the mouse pointer when the mouse pointer is over the control.');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('OnMouseUp - TNotifyEvent');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Occurs when the user releases a mouse button');
AboutWallPaper.Memo.Lines.Add('that was pressed with the mouse pointer over the control.');

AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Methods');
AboutWallPaper.Memo.Lines.Add('_______________________________________________');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Paint - Procedure');
AboutWallPaper.Memo.Lines.Add('');
AboutWallPaper.Memo.Lines.Add('Paints the wallpaper. Usefull for forcing the painting of the wallpaper.');



  { Set result to OK }
    AboutWallPaper.Icon := Application.Icon;
    AboutWallPaper.ShowModal;

AboutWallPaper.Free
end;



function TAboutTypeProperty.GetValue: string;
begin
Result := 'WallPaper';
end;

procedure TAboutTypeProperty.SetValue(const Value: string);
begin
RunAboutBox;
end;

procedure TAboutTypeProperty.Edit;
begin
RunAboutBox;
end;

function TAboutTypeProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

end.
